@@ -1,3 +1,4 @@
+from typing import List
 from pdip.cqrs.decorators.requestclass import requestclass
 
 
@@ -5,3 +6,4 @@ from pdip.cqrs.decorators.requestclass import requestclass
 class CreateUserRequest:
     Name: str = None
     Surname: str = None
+    Phones: List[str] = None
